Index: /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/adapters.py
===================================================================
--- /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/adapters.py	(revision 1646)
+++ /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/adapters.py	(revision 1647)
@@ -24,8 +24,8 @@
         seo_context = queryMultiAdapter((self.context, request), name='seo_context')
         if seo_context:
-            usage_keywords_in_metatags = seo_props.getProperty('usage_keywords_in_metatags', None)
+            filter_keywords_by_content = seo_props.getProperty('filter_keywords_by_content', None)
             meta_keywords = list(seo_context.meta_keywords())
             is_test = self.context.REQUEST.get('without_metatag_keywords', None)
-            if usage_keywords_in_metatags and meta_keywords and is_test is None:
+            if filter_keywords_by_content and meta_keywords and is_test is None:
                 # extract words from url page using lynx browser (test page randered without metatag keywords)
                 text = commands.getoutput('lynx --dump --nolist %s?without_metatag_keywords=1' % self.context.absolute_url()).lower()
Index: /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/browser/templates/seo_controlpanel.pt
===================================================================
--- /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/browser/templates/seo_controlpanel.pt	(revision 1646)
+++ /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/browser/templates/seo_controlpanel.pt	(revision 1647)
@@ -80,12 +80,12 @@
           <div class="field">
             <input type="checkbox"
-                   id="usageKeywordsInMetatags"
-                   name="usageKeywordsInMetatags"
-                   tal:attributes="checked view/getUsageKeywordsInMetatags"/>
-            <label for="usageKeywordsInMetatags" i18n:translate="label_usage_keywords_in_metatags">
-                Usage of keywords, found on the page, in metatags.
+                   id="filterKeywordsByContent"
+                   name="filterKeywordsByContent"
+                   tal:attributes="checked view/getFilterKeywordsByContent"/>
+            <label for="filterKeywordsByContent" i18n:translate="label_filter_keywords_by_content">
+                Filter keywords by content.
             </label>
-            <div class="formHelp" i18n:translate="help_usage_keywords_in_metatags">
-                Usage of keywords, found on the page, in metatags.
+            <div class="formHelp" i18n:translate="help_filter_keywords_by_content">
+                Usage metatags keywords, which present in content.
               </div>
           </div>
Index: /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/profiles/default/propertiestool.xml
===================================================================
--- /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/profiles/default/propertiestool.xml	(revision 1646)
+++ /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/profiles/default/propertiestool.xml	(revision 1647)
@@ -87,5 +87,5 @@
    <element value="distribution seo_distribution"/>
   </property>
-  <property name="usage_keywords_in_metatags" type="boolean">True</property>
+  <property name="filter_keywords_by_content" type="boolean">True</property>
  </object>
  <object name="site_properties" meta_type="Plone Property Sheet">
Index: /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/profiles/reinstall/propertiestool.xml
===================================================================
--- /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/profiles/reinstall/propertiestool.xml	(revision 1646)
+++ /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/profiles/reinstall/propertiestool.xml	(revision 1647)
@@ -21,5 +21,5 @@
    <element value="distribution seo_distribution"/>
   </property>
-  <property name="usage_keywords_in_metatags" type="boolean">True</property>
+  <property name="filter_keywords_by_content" type="boolean">True</property>
   <property name="settings_use_keywords_sg" type="int">1</property>
   <property name="settings_use_keywords_lg" type="int">1</property>
Index: /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/tests/testQSEOptimizerUsageKeywords.py
===================================================================
--- /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/tests/testQSEOptimizerUsageKeywords.py	(revision 1646)
+++ /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/tests/testQSEOptimizerUsageKeywords.py	(revision 1647)
@@ -88,6 +88,6 @@
         self.assert_(m, "No 'foo, bar' keyword find")
 
-    def setup_testing_render_keywords(self):
-        self.my_doc.setText('<p>global local subject</p>')
+    def setup_testing_render_keywords(self, html='<p>global local subject</p>'):
+        self.my_doc.setText(html)
         self.sp.additional_keywords = (('global',))
         self.my_doc.manage_addProperty('qSEO_keywords', ('local'), 'lines')
@@ -136,4 +136,27 @@
         self.assert_(m, "No 'subject, global, local' keywords find")
 
+    def test_default_values_filter_keywords_by_content_in_configlet(self):
+        self.assertEqual(self.sp.getProperty('filter_keywords_by_content', None), True)
+
+    def test_changes_filter_keywords_by_content_in_configlet(self):
+        path = self.portal.id+'/@@seo-controlpanel?filter_keywords_by_content=False&form.submitted=1'
+        self.publish(path, self.basic_auth)
+        self.assertEqual(self.sp.getProperty('filter_keywords_by_content', 0), None)
+
+    def test_filter_keywords_by_content_true(self):
+        # Usage metatags keywords, which present in content (filter_keywords_by_content=True)
+        self.sp.manage_changeProperties(settings_use_keywords_sg=3, settings_use_keywords_lg=2, filter_keywords_by_content=True)
+        self.html = self.setup_testing_render_keywords(html='<p>subject global</p>')
+        m = re.match('.*(<meta\s+(?:(?:name="keywords"\s*)|(?:content="(?:subject|global),\s*(?:subject|global)"\s*)){2}/>)',
+                    self.html, re.S|re.M)
+        self.assert_(m, "In metatags keywords not finded \"subject, global\". Checkbox filter_keywords_by_content in configlet is not working.")
+
+    def test_filter_keywords_by_content_false(self):
+        # Usage metatags keywords, without taking into consideration presece in content (filter_keywords_by_content=False)
+        self.sp.manage_changeProperties(settings_use_keywords_sg=3, settings_use_keywords_lg=2, filter_keywords_by_content=False)
+        self.html = self.setup_testing_render_keywords(html='<p>subject global</p>')
+        m = re.match('.*(<meta\s+(?:(?:name="keywords"\s*)|(?:content="(?:subject|global|local),\s*(?:subject|global|local),\s*(?:subject|global|local)"\s*)){2}/>)',
+                    self.html, re.S|re.M)
+        self.assert_(m, "In metatags keywords not finded \"subject, global, locals\". Checkbox filter_keywords_by_content in configlet is not working.")
 
 def test_suite():

Index: /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/browser/views.py
===================================================================
--- /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/browser/views.py	(revision 1646)
+++ /quintagroup.seoptimizer/trunk/quintagroup/seoptimizer/browser/views.py	(revision 1647)
@@ -278,9 +278,9 @@
         return seo.getProperty('additional_keywords')
 
-    def getUsageKeywordsInMetatags( self ):
-        """ Get values from usage_keywords_in_metatags property in seo_properties.
+    def getFilterKeywordsByContent( self ):
+        """ Get values from filter_keywords_by_content property in seo_properties.
         """
         seo = self.portal_properties.seo_properties
-        return seo.getProperty('usage_keywords_in_metatags')
+        return seo.getProperty('filter_keywords_by_content')
 
     def createMultiColumnList( self ):
@@ -305,5 +305,5 @@
         default_custom_metatags = request.get('default_custom_metatags', [])
         metatags_order = request.get('metatags_order', [])
-        usageKeywordsInMetatags = request.get('usageKeywordsInMetatags', None)
+        filterKeywordsByContent = request.get('filterKeywordsByContent', None)
         settingsUseKeywordsSG = int(request.get('settingsUseKeywordsSG', 1))
         settingsUseKeywordsLG = int(request.get('settingsUseKeywordsLG', 1))
@@ -321,5 +321,5 @@
             seo_props.manage_changeProperties(metatags_order=metatags_order)
             seo_props.manage_changeProperties(content_types_seoprops_enabled=content_types_seoprops_enabled)
-            seo_props.manage_changeProperties(usage_keywords_in_metatags=usageKeywordsInMetatags)
+            seo_props.manage_changeProperties(filter_keywords_by_content=filterKeywordsByContent)
             seo_props.manage_changeProperties(settings_use_keywords_sg=settingsUseKeywordsSG)
             seo_props.manage_changeProperties(settings_use_keywords_lg=settingsUseKeywordsLG)